# nspyre

[![GitHub](https://img.shields.io/github/v/release/nspyre-org/nspyre?label=GitHub)](https://github.com/nspyre-org/nspyre/)
[![PyPi version](https://img.shields.io/pypi/v/nspyre)](https://pypi.org/project/nspyre/)
[![conda-forge version](https://img.shields.io/conda/v/conda-forge/nspyre)](https://github.com/conda-forge/nspyre-feedstock)
[![License](https://img.shields.io/github/license/nspyre-org/nspyre)](https://github.com/nspyre-org/nspyre/blob/master/LICENSE)
[![Docs build](https://readthedocs.org/projects/nspyre/badge/?version=latest)](https://nspyre.readthedocs.io/en/latest/?badge=latest)
[![conda-forge platform](https://img.shields.io/conda/pn/conda-forge/nspyre)](https://github.com/conda-forge/nspyre-feedstock)
[![DOI](https://zenodo.org/badge/220515183.svg)](https://zenodo.org/badge/latestdoi/220515183)

(N)etworked (S)cientific (Py)thon (R)esearch (E)nvironment.

See https://nspyre.readthedocs.io/.

# What is nspyre?

nspyre is a Python package for conducting scientific experiments. It provides 
a set of tools to allow for control of instrumentation, data collection, 
real-time plotting, as well as GUI generation. Anyone in the research or 
industrial spaces using computer-controlled equipment and collecting data can 
potentially benefit from using nspyre to run their experiments.

The hardware being controlled can be connected either locally on the machine 
running the experimental logic, or on a remote machine, which can be accessed 
in a simple, pythonic fashion. This allows for the easy integration of shared 
instrumentation in a research environment. Data collection is also 
networked, and allows for real-time viewing locally, or from a remote machine. 
nspyre provides a set of tools for quickly generating a Qt-based GUI for 
control and data viewing.

If you use nspyre for an experiment, we would really appreciate it if you 
[cite](https://doi.org/10.5281/zenodo.7315077) it in your publication!
